IWrapper_helpers {#master}
----------------

## Libraries

### `dev`

* Added the new `WrapperSingle` and `WrapperMultiple` helper classes, that
  inherit from both `IWrapper` and `IMultipleWrapper` but require to implement
  only one of these interfaces.
